@@ -183,7 +183,7 @@ class PlotManager(object):
         self.plots[plot_id] = plot
         if len(self.plots) == 1:
             self.default_plot = plot
-        plot.set_manager(self, id)
+        plot.set_manager(self, plot_id)
         # Connecting signals
         plot.connect(plot, SIG_ITEMS_CHANGED, self.update_tools_status)
         plot.connect(plot, SIG_ACTIVE_ITEM_CHANGED, self.update_tools_status)
@@ -690,7 +690,8 @@ class BaseCurveWidget(QSplitter):
     """
     def __init__(self, parent=None, title=None,
                  xlabel=None, ylabel=None, xunit=None, yunit=None,
-                 section="plot", show_itemlist=False, gridparam=None):
+                 section="plot", show_itemlist=False, gridparam=None,
+                 curve_antialiasing=None):
         QSplitter.__init__(self, Qt.Horizontal, parent)
         
         self.setSizePolicy(QSizePolicy.Expanding, QSizePolicy.Expanding)
@@ -698,6 +699,8 @@ class BaseCurveWidget(QSplitter):
         self.plot = CurvePlot(parent=self, title=title, xlabel=xlabel,
                               ylabel=ylabel, xunit=xunit, yunit=yunit,
                               section=section, gridparam=gridparam)
+        if curve_antialiasing is not None:
+            self.plot.set_antialiasing(curve_antialiasing)
         self.addWidget(self.plot)
         self.itemlist = PlotItemList(self)
         self.itemlist.setVisible(show_itemlist)
@@ -733,7 +736,7 @@ class CurveWidget(BaseCurveWidget, PlotManager):
                 self.add_panel(panel)
 
 class CurveWidgetMixin(PlotManager):
-    def __init__(self, wintitle="guiqwt plot", icon="guiqwt.png",
+    def __init__(self, wintitle="guiqwt plot", icon="guiqwt.svg",
                  toolbar=False, options=None, panels=None):
         PlotManager.__init__(self, main=self)
 
@@ -767,7 +770,8 @@ class CurveWidgetMixin(PlotManager):
         self.setWindowTitle(wintitle)
         if isinstance(icon, basestring):
             icon = get_icon(icon)
-        self.setWindowIcon(icon)
+        if icon is not None:
+            self.setWindowIcon(icon)
         self.setMinimumSize(320, 240)
         self.resize(640, 480)
 
@@ -812,11 +816,12 @@ class CurveDialog(QDialog, CurveWidgetMixin):
         * parent: parent widget
         * panels (optional): additionnal panels (list, tuple)
     """
-    def __init__(self, wintitle="guiqwt plot", icon="guiqwt.png", edit=False,
+    def __init__(self, wintitle="guiqwt plot", icon="guiqwt.svg", edit=False,
                  toolbar=False, options=None, parent=None, panels=None):
         QDialog.__init__(self, parent)
         self.edit = edit
         self.button_box = None
+        self.button_layout = None
         CurveWidgetMixin.__init__(self, wintitle=wintitle, icon=icon, 
                                   toolbar=toolbar, options=options,
                                   panels=panels)
@@ -856,7 +861,7 @@ class CurveWindow(QMainWindow, CurveWidgetMixin):
         * parent: parent widget
         * panels (optional): additionnal panels (list, tuple)
     """
-    def __init__(self, wintitle="guiqwt plot", icon="guiqwt.png",
+    def __init__(self, wintitle="guiqwt plot", icon="guiqwt.svg",
                  toolbar=False, options=None, parent=None, panels=None):
         QMainWindow.__init__(self, parent)
         CurveWidgetMixin.__init__(self, wintitle=wintitle, icon=icon, 
@@ -903,7 +908,7 @@ class BaseImageWidget(QSplitter):
                  colormap="jet", aspect_ratio=1.0, lock_aspect_ratio=True,
                  show_contrast=False, show_itemlist=False, show_xsection=False,
                  show_ysection=False, xsection_pos="top", ysection_pos="right",
-                 gridparam=None):
+                 gridparam=None, curve_antialiasing=None):
         QSplitter.__init__(self, Qt.Vertical, parent)
         
         self.setSizePolicy(QSizePolicy.Expanding, QSizePolicy.Expanding)
@@ -915,6 +920,8 @@ class BaseImageWidget(QSplitter):
                               yreverse=yreverse, aspect_ratio=aspect_ratio,
                               lock_aspect_ratio=lock_aspect_ratio,
                               gridparam=gridparam)
+        if curve_antialiasing is not None:
+            self.plot.set_antialiasing(curve_antialiasing)
 
         from guiqwt.cross_section import YCrossSection
         self.ycsw = YCrossSection(self, position=ysection_pos,
